""" TW2 fancy slidey menu that I made just for you!

Slideymenu is best demonstrated by its use in `narcissus
<http://narcissus.rc.rit.edu>`_.  Definitely check it out.

You can also see it in the `tw2 WidgetBrowser
<http://tw2-demos.threebean.org/module?module=tw2.slideymenu>`_ although it
doesn't do it justice.

Get the source from http://github.com/toscawidgets/tw2.slideymenu
"""

from widgets import *
